@@ -1,10 +1,8 @@
-
-
 from skinnywms.wmssvr import application
 
 
 __all__ = [
-    'main',
+    "main",
 ]
 
 
@@ -12,5 +10,5 @@ def main():
     application.run(debug=True, threaded=False)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
